@@ -616,7 +616,23 @@ ggthemes_data <- {
              -0x2796, # heavy minus sign
              -0x2759 # medium vertical bar)
              ))
+
+    x$fivethirtyeight <-
+        c(dkgray = rgb(60, 60, 60, max = 255),
+          medgray = rgb(210, 210, 210, max = 255),
+          ltgray = rgb(240, 240, 240, max = 255),
+          red = rgb(255, 39, 0, max = 255),
+          blue = rgb(0, 143, 213, max = 255),
+          green = rgb(119, 171, 67, max = 255))
     
+    x$hc <- list()
+    x$hc$palettes <- list()
+    x$hc$palettes$default <- c("#7cb5ec", "#434348", "#90ed7d", "#f7a35c", 
+                               "#8085e9", "#f15c80", "#e4d354", "#8085e8", "#8d4653", "#91e8e1")
+    x$hc$palettes$darkunica <- c("#2b908f", "#90ee7e", "#f45b5b", "#7798BF", "#aaeeee", "#ff0066", "#eeaaee",
+                                 "#55BF3B", "#DF5353", "#7798BF", "#aaeeee")
+    x$hc$bg <- c(default = "#FFFFFF",
+                 darkunica = "#2a2a2b")
     ## Return
     x
 
